@@ -8,7 +8,7 @@ $DTL::Fast::FILTER_HANDLERS{'get_digit'} = __PACKAGE__;
 sub parse_parameters
 {
     my $self = shift;
-    die "No digit number specified"
+    die $self->get_parse_error("no digit number specified")
         if not scalar @{$self->{'parameter'}};
     $self->{'digit'} = $self->{'parameter'}->[0];
     return $self;
@@ -17,10 +17,7 @@ sub parse_parameters
 #@Override
 sub filter
 {
-    my $self = shift;  # self
-    shift;  # filter_manager
-    my $value = shift;  # value
-    my $context = shift;    #context
+    my ($self, $filter_manager, $value, $context) = @_;
     
     my $digit = $self->{'digit'}->render($context);
     if(
