@@ -8,7 +8,7 @@ $DTL::Fast::FILTER_HANDLERS{'removetags'} = __PACKAGE__;
 sub parse_parameters
 {
     my $self = shift;
-    die "No tags to remove specified"
+    die $self->get_parse_error("no tags to remove specified")
         if not scalar @{$self->{'parameter'}};
     $self->{'tags'} = $self->{'parameter'}->[0];
     return $self;
@@ -17,10 +17,7 @@ sub parse_parameters
 #@Override
 sub filter
 {
-    my $self = shift;  # self
-    shift;  # filter_manager
-    my $value = shift;
-    my $context = shift;
+    my( $self, $filter_manager, $value, $context ) = @_;
     
     my $tags_re = join '|', (split /\s+/, $self->{'tags'}->render($context));
     
