@@ -1,7 +1,6 @@
 package DTL::Fast::Tag::Verbatim;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Tag';  
-
 $DTL::Fast::TAG_HANDLERS{'verbatim'} = __PACKAGE__;
 
 use DTL::Fast::Text;
@@ -15,8 +14,8 @@ sub parse_parameters
     my $self = shift;
     $self->{'contents'} = DTL::Fast::Text->new();
     $self->{'last_tag'} = $self->{'parameter'} ?
-        sprintf( '{%% %s %s %%}', $self->get_close_tag, $self->{'parameter'})
-        : '{% endverbatim %}';
+        qr/\Qendverbatim\E\s+\Q$self->{'parameter'}\E/
+        : 'endverbatim';
     return $self;
 }
 
@@ -25,8 +24,9 @@ sub parse_next_chunk
 {
     my $self = shift;
     my $chunk = shift @{$self->{'raw_chunks'}};
+    my $chunk_lines = scalar (my @tmp = $chunk =~ /(\n)/g ) || 0;
     
-    if( $chunk eq $self->{'last_tag'} )
+    if( $chunk =~ /^\{\%\s*$self->{'last_tag'}\s*\%\}$/six )
     {
         $self->{'raw_chunks'} = []; # this stops parsing
     }
@@ -34,6 +34,8 @@ sub parse_next_chunk
     {
         $self->{'contents'}->append($chunk);
     }
+
+    $DTL::Fast::Template::CURRENT_TEMPLATE_LINE += $chunk_lines;
     
     return;
 }
